==========================================
A toolbox to work with R projects on Renku
==========================================

.. image:: https://img.shields.io/badge/license-apache2-brightgreen.svg
   :target: https://github.com/auwerxlab/renku-r-tools/blob/master/LICENSE

.. image:: https://img.shields.io/github/v/release/auwerxlab/renku-r-tools
   :target: https://github.com/auwerxlab/renku-r-tools/releases

.. image:: https://img.shields.io/pypi/v/renku-r-tools
   :target: https://pypi.python.org/pypi/renku-r-tools

.. image:: https://readthedocs.org/projects/renku-r-tools/badge/?version=latest
   :target: https://renku-r-tools.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

Documentation
=============

.. toctree::
   :maxdepth: 4

   cli
   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
